==> theme-1.0.3.zip: adw/js/main.js <==
// Brand Center theme scripts
theme = {
    path : '/wp-content/themes/adw-theme/',
}

// console.log('Brand Center init');
jQuery(document).ready(function($) {
    /*
    * Mobile Menu
    */
    if ($('#mobile-nav').length) {
        $('#mobile-nav').slicknav({
            appendTo : 'header',
        });
    }

    /*
    * Carousels
    */
    //if ($('.carousel-block').length) {
    //    $('.carousel-block').each(function(){
    //        var autoplay = $(this).attr('data-autoplay') ? true : false;
    //        var autoplayspeed = $(this).attr('data-autoplayspeed');
    //        if(autoplayspeed < 2000) {
    //            autoplayspeed = 2000;
    //        }
    //        $(this).children('.acf-innerblocks-container').slick({
    //            arrows: true,
    //            dots: true,
    //            slidesToShow: 1,
    //            autoplay: autoplay,
    //            autoplaySpeed: autoplayspeed,
    //        });
    //    });
    //}

    const navbar = document.querySelector("header");
    const navbarOffset = navbar.offsetTop;
    const navbarHeight = navbar.offsetHeight;

    function stickyNav() {
      if (window.pageYOffset >= navbarOffset) {
        navbar.classList.add("sticky");
        document.querySelector('main').style.paddingTop = `${navbarHeight}px`;
      } else {
        navbar.classList.remove("sticky");
      }
    }

    // Fade-in content on sroll
    function isScrolledIntoView(elem) {
        const docViewTop = $(window).scrollTop();
        const docViewBottom = docViewTop + $(window).height();
        const elemTop = $(elem).offset().top;
        const elemBottom = elemTop + $(elem).height();
        return ((elemBottom <= docViewBottom) && (elemTop >= docViewTop));
    }

    window.onscroll = function(){
        stickyNav()

        $('.fade-on-scroll').each(function(){
            if(isScrolledIntoView(this)){
                $(this).addClass('fade-in');
            }
        });
    }

    $("a").on('click', function(event) {
        if (this.hash !== "") {
          event.preventDefault();
          const hash = this.hash;

          $('html, body').animate({
            scrollTop: $(hash).offset().top - navbarHeight,
            easing: 'easein',
          }, 600, function(){
            window.location.hash = hash;
          });
        }
    });
});

==> theme-1.0.4.zip: adw/js/main.js <==
// Brand Center theme scripts
theme = {
    path : '/wp-content/themes/adw-theme/',
}

// console.log('Brand Center init');
jQuery(document).ready(function($) {
    /*
    * Mobile Menu
    */
    if ($('#mobile-nav').length) {
        $('#mobile-nav').slicknav({
            appendTo : 'header',
        });
    }

    /*
    * Carousels
    */
    //if ($('.carousel-block').length) {
    //    $('.carousel-block').each(function(){
    //        var autoplay = $(this).attr('data-autoplay') ? true : false;
    //        var autoplayspeed = $(this).attr('data-autoplayspeed');
    //        if(autoplayspeed < 2000) {
    //            autoplayspeed = 2000;
    //        }
    //        $(this).children('.acf-innerblocks-container').slick({
    //            arrows: true,
    //            dots: true,
    //            slidesToShow: 1,
    //            autoplay: autoplay,
    //            autoplaySpeed: autoplayspeed,
    //        });
    //    });
    //}

    const navbar = document.querySelector("header");
    const navbarOffset = navbar.offsetTop;
    const navbarHeight = navbar.offsetHeight;

    function stickyNav() {
      if (window.pageYOffset >= navbarOffset) {
        navbar.classList.add("sticky");
        document.querySelector('main').style.paddingTop = `${navbarHeight}px`;
      } else {
        navbar.classList.remove("sticky");
      }

      if($('.sticky-banner-button').length){
        const $stickyBanner = $('.sticky-banner-button');
        const bannerHeight = $stickyBanner[0].offsetHeight;
        if (window.pageYOffset >= navbarOffset) {
          $stickyBanner.addClass("sticky");
          $stickyBanner.css('top', navbarOffset + navbarHeight -1 +'px' )
        } else {
          $stickyBanner.removeClass("sticky");
          $stickyBanner.css('top', 'unset' )
        }
      }
    }

    // Fade-in content on sroll
    function isScrolledIntoView(elem) {
        const docViewTop = $(window).scrollTop();
        const elemTop = $(elem).offset().top;
        return ((elemTop >= docViewTop));
    }
    $('.fade-in-on-scroll').each(function(){
      if(isScrolledIntoView(this)){
          $(this).addClass('fade-in');
      }
  });

    window.onscroll = function(){
        stickyNav()

        $('.fade-in-on-scroll').each(function(){
            if(isScrolledIntoView(this)){
                $(this).addClass('fade-in');
            }
        });
    }

    $("a").on('click', function(event) {
        if (this.hash !== "") {
          event.preventDefault();
          const hash = this.hash;

          $('html, body').animate({
            scrollTop: $(hash).offset().top - navbarHeight,
            easing: 'easein',
          }, 600, function(){
            window.location.hash = hash;
          });
        }
    });

    $('.slide-in-out-toggle').on('click', function(e){
      e.preventDefault();
      target = $(this).attr('data-target');
      $target = $(target);

      $(this).toggleClass('active');

      if($target.hasClass('slide-in')) {
        $(target).removeClass('slide-in');
        $(target).addClass('slide-out');
      } else {
        $(target).addClass('slide-in');
        $(target).removeClass('slide-out');
      }
    });

    $('.close-container').on('click', function(e){
      e.preventDefault();
      $container = $(this).closest('.slide-in-out-container');
      $(target).removeClass('slide-in');
      $(target).addClass('slide-out');
    });
});
